# Autorok

## Brief overview

Autorok is a python wrapper around sigrok-cli and libsigrok/libsigrok4DSL, which provides all common functionalities
from those binaries/executables.

Allows for easier sigrok automation using Python language, for tasks such as HW testing.

## Supported interfaces

Currently supported interfaces are

- SigrokCLI

Planned interfaces to support are:

- Libsigrok
- Libsigrok4DSL

## Used methodology to create this project

This project is made with technique called "AMDD", which a short form of term 'Agile Model Driven Development'

In summary:

1. Model a thing you want to code

2. Write a test to this model

3. Write implementation against written test which was based on a model

This is basically extension of TDD (Test Driven Development) with architecture/modelling SW stuff. My modelling skills still sucks, but I will get better soon (I hope :) )

Link to AMDD: [Agile Model Driven Development (AMDD): The Key to Scaling Agile Software Development](http://www.agilemodeling.com/essays/amdd.htm)

Corresponding Models folder is available [here](https://git.sr.ht/~khazakar/KhazAkar-AMDD-models)

## Wingware donation

I'm thankful to Wingware for generous donation of their great Wing IDE Pro license for such small project.

Those guys really works their hats off to provide really great experience :)

I highly recommend checking them out!

[Wingware](https://wingware.com)
